{% extends "main.html" %}
{% load karaage_tags %}
{% load filters %}
{% load humanize %}


{% block title %}Institute Trends{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    <a href="{% url 'kg_usage' %}">Usage</a>&nbsp;›
</div>
{% endblock %}


{% block content %}
<div id="content-main">
    <p>{% date_filter start end %}</p>
    {% for g in graph_list %}
    <div class="module">
        <h2>{{ g.institute }}</h2>

        <img id="graph" src="{{ g.graph_url }}"/><br/>
        <p><a href="{{ g.data_url }}">data</a></p>

    </div>
    {% endfor %}
</div>
{% endblock %}
