# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-03-12 08:05
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kgapplications', '0005_auto_20180302_1808'),
    ]

    operations = [
        migrations.AlterField(
            model_name='applicant',
            name='saml_id',
            field=models.CharField(blank=True, editable=False, max_length=200, null=True),
        ),
    ]
