{% extends "forms.html" %}
{% load forms %}


{% block title %}
{% if account %}Edit Account{% else %}Create Account{% endif %}
{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    <a href="{% url 'kg_person_list' %}">People</a>&nbsp;›
    <a href="{% url 'kg_person_detail' person.username %}">{{ person }}</a>&nbsp;›
    {% if account %}
        {{ account.username }}&nbsp;›
        Edit
    {% else %}
        Create Account
    {% endif %}
</div>
{% endblock %}


{% block content %}
<div class="module">
    <h2>Edit Account</h2>

    <form method="post" action=".">{% csrf_token %}
        {{ form.non_field_errors }}
        {% form_as_div form %}

        <div class="submit-row">
            <input type="submit" value="Save" class="default" />
        </div>
    </form>
</div>
{% endblock %}
