{% extends "forms.html" %}


{% block title %}Delete Account{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    <a href="{% url 'kg_person_list' %}">People</a>&nbsp;›
    <a href="{% url 'kg_person_detail' account.person.username %}">{{ account.username }}</a>&nbsp;›
    {{ account.username }}&nbsp;›
    Delete
</div>
{% endblock %}


{% block content %}
    <h1>Are you sure?</h1>
    <p>Are you sure you want to delete {{ account.person }}'s user account with username {{ account.username }}? </p>
    <form method="post" action=".">{% csrf_token %}
        <div>
            <input type="hidden" name="post" value="yes" />
            <input type="submit" value="Yes, I'm sure" />
        </div>
    </form>
{% endblock %}
