{% extends "forms.html" %}


{% block title %}Edit Applicant{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    <a href="{% url 'kg_application_list' %}">Applications</a>&nbsp;›
    Edit Applicant
</div>
{% endblock %}


{% block content %}
<div class="module">
    <h2>Applicant</h2>
    <form method="post" action=".">{% csrf_token %}
        {% load forms %}
        <fieldset class="aligned ()">
            {% form_as_div form %}
        </fieldset>

        <div class="submit-row">
            <input type="submit" value="Save" class="default" />
        </div>
    </form>
</div>
{% endblock %}
