{% load karaage_tags %}
{% load usage %}
{% load render_table from django_tables2 %}
{% get_machine_recent_usage machine as usage_list %}
<div class="module">
    <h2>Latest Usage</h2>
    {% render_table usage_list %}
    <div class="object-tools">
        <ul>
            <li><a href="{% url 'kg_usage_job_list' %}{% url_with_param machine=machine.pk %}">Display all jobs</a></li>
        </ul>
    </div>
</div>
