{% extends "forms.html" %}


{% block title %}Edit Software{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    <a href="{% url 'kg_software_list' %}">Software</a>&nbsp;›
    {% if object %}
        <a href="{% url 'kg_software_detail' object.pk %}">{{ object }}</a>&nbsp;›
        Edit
    {% else %}
        Create Software
    {% endif %}
</div>
{% endblock %}


{% block content %}
<form method="post" action=".">{% csrf_token %}
    {% load forms %}
    <fieldset class="aligned ()">
        {% form_as_div form %}
    </fieldset>

    <div class="submit-row">
        <input type="submit" value="Save" class="default" />
    </div>
</form>
{% endblock %}
