{% extends "forms.html" %}


{% block title %}Change Password{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    <a href="{% url 'kg_person_list' %}">People</a>&nbsp;›
    <a href="{{ person.get_absolute_url }}">{{ person }}</a>&nbsp;›
    Change Password
</div>
{% endblock %}


{% block content %}
{% if form.has_errors %}
<p class="error">Your username and password didn't match. Please try again.</p>
{% endif %}

<p>This page will allow you to change the password for this instance of
Karaage and associated systems (e.g., ssh logins to clusters).</p>

<p>Enter the new password twice so we can verify you typed it in correctly.</p>

<form method="post" action=".">{% csrf_token %}
    {% load forms %}
    <div>
        {{ form.non_field_errors }}
        {% form_as_div form %}
    </div>
    <input type="submit" value="Change password" />
</form>
{% endblock %}
