/* DATE AND TIME */

p.datetime {
    line-height: 20px;
    margin: 0;
    padding: 0;
    color: #666;
    font-size: 11px;
    font-weight: bold;
}

.datetime span {
    font-size: 11px;
    color: #ccc;
    font-weight: normal;
    white-space: nowrap;
}

table p.datetime {
    font-size: 10px;
    margin-left: 0;
    padding-left: 0;
}

/* FILE UPLOADS */

.file-upload a {
    font-weight: normal;
}

.file-upload .deletelink {
    margin-left: 5px;
}

span.clearable-file-input label {
    color: #333;
    font-size: 11px;
    display: inline;
    float: none;
}

/* EDIT INLINE */

.editinline button.addlink {
    border: 0 none;
    color: #5b80b2;
    font-size: 100%;
    cursor: pointer;
}

.editinline button.addlink:hover {
    color: #036;
    cursor: pointer;
}

.editinline table .help {
    text-align: right;
    float: right;
    padding-left: 2em;
}

.editinline tfoot .addlink {
    white-space: nowrap;
}

.editinline table thead th:last-child {
    border-left: none;
}

.editinline tr.deleted {
    background: #ddd url(../img/deleted-overlay.gif);
}

.editinline tr.deleted td:hover {
    cursor: default;
}

.editinline tr.deleted td:first-child {
    background-image: none !important;
}

/* EDIT INLINE - STACKED */

