{% extends "main.html" %}

{% block title %}Error 404{% endblock %}


{% block content_title %}{% endblock %}

{% block content %}
<div id="content-main">
    <h3>Error 404</h3>
    <p>Document Not Found</p>
</div>
{% endblock %}
