{% extends "karaage/common/profile_base.html" %}
{% load render_table from django_tables2 %}


{% block title %}Institutes - My profile{% endblock %}
{% block profile_title %}Institutes{% endblock %}


{% block profile_content %}
<div class="module">
    <h2>My Institutes</h2>
    {% render_table my_institute_list %}
</div>

<div class="module">
    <h2>Delegate for</h2>
    {% render_table delegate_institute_list %}
</div>
{% endblock %}
