{% extends "main.html" %}
{% load render_table from django_tables2 %}


{% block title %}Search{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    Search
</div>
{% endblock %}


{% block content %}
<div id="content-main">
    <div class="module">
    <h2>People</h2>
    {% render_table people_list %}
    </div>

    <div class="module">
    <h2>Groups</h2>
    {% render_table group_list %}
    </div>

    <div class="module">
    <h2>Projects</h2>
    {% render_table project_list %}
    </div>
</div>
{% endblock %}
 
