{% extends "main.html" %}


{% block title %}Software Categories{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href='{% url "index" %}'>Home</a>&nbsp;›
    <a href="{% url 'kg_software_list' %}">Software</a>&nbsp;›
    Categories
</div>
{% endblock %}


{% block content %}
<div id="content-main">
    <div class="module">
        <h2>Software categories</h2>
        <div class="table-container">
            <table cellspacing="0">
                <thead>
                    <tr>
                        <th>Name</th>
                    </tr>
                </thead>
                <tbody>
                    {% for c in category_list %}
                    <tr>
                        <td><a href="{% url 'kg_software_category_edit' c.id %}">{{ c.name }}</a></td>
                    </tr>
                    {% endfor %}
                </tbody>
            </table>
        </div>
        {% if is_admin %}
        <div class="object-tools">
            <ul>
                <li><a href="{% url 'kg_software_category_create' %}" class="addlink">Add category</a></li>
            </ul>
        </div>
        {% endif %}
    </div>
</div>
{% endblock %}
