{% extends "karaage/common/profile_base.html" %}

{% block title %}Edit personal details - My profile{% endblock %}
{% block profile_title %}Edit personal details{% endblock %}


{% block profile_content %}
<div class="module">
    <h2>Edit personal details</h2>
    <form method="post" action=".">{% csrf_token %}
        <div>
            {% load forms %}
            {% if form.errors  or form.non_field_errors %}
            <p class="errornote">Please correct the error{{ form.errors|pluralize }} below.</p>
            {% endif %}
            <fieldset class="aligned ()">
            {{ form.non_field_errors }}
            {% formfield form.title %}
            {% inlineformfield form.short_name form.full_name %}
            {% inlineformfield form.department form.position %}
            {% formfield form.supervisor %}
            {% formfield form.email %}
            {% inlineformfield form.telephone form.mobile %}
            {% formfield form.fax %}
            {% formfield form.address %}
            </fieldset>
        </div>

        <div class="submit-row">
            <input type="submit" value="Save" class="default" />
        </div>
    </form>
</div>
{% endblock %}
