{% extends "karaage/common/profile_base.html" %}
{% load render_table from django_tables2 %}


{% block title %}Applications{% endblock %}


{% block profile_content %}
<div class="module">
    <h2>My applications</h2>
    {% render_table my_applications %}
</div>

<div class="module">
    <h2>Requires Attention</h2>
    {% render_table requires_attention %}
</div>
{% endblock %}
