# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-03-01 17:21
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('kgapplications', '0003_remove_projectapplication_machine_categories'),
    ]

    operations = [
        migrations.AlterField(
            model_name='applicant',
            name='institute',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='karaage.Institute'),
        ),
    ]
