{% extends "base.html" %}
{% load i18n %}

{% block site_name_title %}{% trans 'Karaage' %}&nbsp;|&nbsp;{{ org_name }}{% endblock %}

{% block branding %}
<h1 id="site-name">{{ org_name }} / {% trans 'Karaage' %}</h1>
{% endblock %}
