{% extends "forms.html" %}
{% load forms %}

{% block title %}Password reset{% endblock %}

{% block content %}

{% if validlink %}
<h1>Enter new password</h1>

<p>This page will allow you to change your password for this instance of
Karaage and associated systems (e.g., ssh logins to clusters).</p>

<p>Please enter your new password twice so we can verify you typed it in correctly.</p>

<form action="" method="post">{% csrf_token %}
<div>
<fieldset class="aligned ()">
{% formfield form.new_password1 %}
{% formfield form.new_password2 %}
</fieldset>
</div>
<input type="submit" value="Change my password" />
</form>

{% else %}

<h1>Password reset unsuccessful</h1>

<p>The password reset link was invalid, possibly because it has already been used.  Please request a new password reset.</p>

{% endif %}

{% endblock %}
