{% extends "karaage/common/profile_base.html" %}


{% block title %}Password Change - My profile{% endblock %}
{% block profile_title %}Password Change{% endblock %}


{% block profile_content %}
<div class="module">
    <h2>Password Change</h2>

    {% if form.has_errors %}
    <p class="error">Your username and password didn't match. Please try again.</p>
    {% endif %}

    <p>This page will allow you to change the password for this instance of
    Karaage and associated systems (e.g., ssh logins to clusters).</p>

    <p>Please enter your old password, for security's sake, and then enter your
    new password twice so we can verify you typed it in correctly.</p>

    <p>If you do not know your old password, you can request to <a href="{% url 'kg_profile_reset' %}">Reset your Password</a>.</p>

    <form action="." method="post">{% csrf_token %}
        {% load forms %}
        <div>
            <fieldset class="aligned ()">
            {{ form.non_field_errors }}
            {% formfield form.old %}
            {% formfield form.new1 %}
            {% formfield form.new2 %}
            </fieldset>
        </div>
        <input type="submit" value="Change my password"/>
    </form>
</div>
{% endblock %}
